( cd usr/lib/gnopernicus-1.0 ; rm -rf libbrl.so )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libbrl.so.5.0.0 libbrl.so )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libbrl.so.5 )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libbrl.so.5.0.0 libbrl.so.5 )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libke.so )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libke.so.5.0.0 libke.so )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libke.so.5 )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libke.so.5.0.0 libke.so.5 )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libmag.so )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libmag.so.5.0.0 libmag.so )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libmag.so.5 )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libmag.so.5.0.0 libmag.so.5 )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libsrconf.so )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libsrconf.so.5.0.0 libsrconf.so )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libsrconf.so.5 )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libsrconf.so.5.0.0 libsrconf.so.5 )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libsrlow.so )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libsrlow.so.5.0.0 libsrlow.so )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libsrlow.so.5 )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libsrlow.so.5.0.0 libsrlow.so.5 )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libsrs.so )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libsrs.so.5.0.0 libsrs.so )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libsrs.so.5 )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libsrs.so.5.0.0 libsrs.so.5 )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libsrutil.so )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libsrutil.so.5.0.0 libsrutil.so )
( cd usr/lib/gnopernicus-1.0 ; rm -rf libsrutil.so.5 )
( cd usr/lib/gnopernicus-1.0 ; ln -sf libsrutil.so.5.0.0 libsrutil.so.5 )
# Update the X font indexes:
if [ -x /usr/X11R6/bin/fc-cache ]; then
  /usr/X11R6/bin/fc-cache -f
fi
if [ -x /usr/bin/scrollkeeper-update ]; then
  /usr/bin/scrollkeeper-update -p /var/lib/scrollkeeper 1> /dev/null 2> /dev/null
fi
